@@ -1,19 +1,19 @@
 /* Definitions needed by the Fortran interface (fevaluate.c) */
 
-#ifndef TVIL_FORTRAN_H
-#define TVIL_FORTRAN_H
+#ifndef _TVIL_FORTRAN_H_
+#define _TVIL_FORTRAN_H_
 
 /*
   These values must match the types used in the calling Fortran
   programs.  TVIL_REAL_SIZE_F should be set to the size in bytes of
-  the TVIL_REAL_F type.  The calling Fortran program should then use
+  the TVIL_REAL_F type. The calling Fortran program should then use
   REAL type
 
   REAL*(TVIL_FORT_SIZE) 
 */
 
-/* YOU MAY WISH TO UNCOMMENT THE FOLLOWING IF YOUR FORTRAN COMPILER
-   SUPPORTS REAL*16/COMPLEX*32 */
+/* Uncomment the following if your FORTRAN program uses
+   REAL*16/COMPLEX*32 */
 /*  #define TVIL_REAL_F       long double */
 /*  #define TVIL_COMPLEX_F    long double complex */
 /*  #define TVIL_REAL_SIZE_F  16 */
