@@ -2,17 +2,17 @@
    should be careful to insure that there are no name conflicts with
    their own variables or functions. */
 
-#ifndef TSIL_GLOBAL_H
-#define TSIL_GLOBAL_H
+#ifndef _TVIL_GLOBAL_H_
+#define _TVIL_GLOBAL_H_
 
 /* Status codes (status) */
 enum {UNEVALUATED, ANALYTIC, REAXIS, CONTOUR};
 
-/* Number of each type of function (could just be hardwired) */
-#define NUM_I_FUNCS 16
-#define NUM_F_FUNCS 12
-#define NUM_E_FUNCS 3
-#define NUM_G_FUNCS 6
+/* Function codes (mode) */
+enum {ALL, EFGH=0, FULL=0, EFG, EF, THREESCALE_A, THREESCALE_B, THREESCALE_C};
+
+/* Print styles */
+enum {STANDARD, BASIC=0, STD=0, GENERIC=0, PLAIN=0, MATH};
 
 /* Maximum number of posible poles on Re t axis: */
 /* So far this is poles associated with I functions (32) and FBAR
@@ -34,8 +34,24 @@ enum {wuxy, wvxz, xuwy, xvwz, uvyz, uwxy,
 enum {_3145, _3246, _4135, _4236, _1256, _1345, 
       _5126, _5134, _2156, _2346, _6125, _6234};
 
+/* DGR would be nice to make above enums for F align with these... */
+enum {Ewuxy, Evwxz, Euvyz};
+
 enum {Gwuzvy, Gxuvyz, Guvxwz, Gyvwxz, Gvuxwy, Gzuwxy};
 enum {wuzvy, xuvyz, uvxwz, yvwxz, vuxwy, zuwxy};
 enum {_31625, _41256, _12436, _52346, _21435, _61345};
 
-#endif /* tsil_global.h */
+/* Allowed permutations */
+enum {P123456, P164352, P245163, P321546, P416235, P461532, P542613, P635124,
+      P132654, P213465, P254361, P356241, P425136, P524316, P563412, P641523, 
+      P146253, P231564, P312645, P365142, P452631, P536214, P614325, P653421};
+
+/* Function types: */
+enum {ITYPE, FBARTYPE, GTYPE, HTYPE, FTYPE, ETYPE};
+
+/* For 3-scale evaluation: */
+enum {_z00xx, _zxxyy=0, _zxyxy=0, _x0yxz, _y0xyz,
+      _0xyz=0, _z0xy, _x0yz, _y0xz,
+      _xxz=0, _yyz, _xyz};
+
+#endif /* tvil_global.h */
